@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::LiveJournal;
 {
-  $WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1810';
+  $WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1812';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::LiveJournal - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1810
+version 0.1812
 
 =head1 DESCRIPTION
 
@@ -481,12 +481,12 @@ sub parse_chapter_urls {
 	    $chapters[$i] = sprintf('%s?format=light', $chapters[$i]);
 	}
     }
-    if (@chapters == 1 and $user)
+    if (@chapters <= 1 and $user)
     {
-	warn "user=$user\n" if ($self->{verbose} > 1);
+	warn "parse_chapter_urls: user=$user\n" if ($self->{verbose} > 1);
 	if ($args{is_community})
 	{
-	    while ($content =~ m/href="(http:\/\/community\.livejournal\.com\/${user}\/\d+.html)(#cutid\d)?">/sg)
+	    while ($content =~ m/href="(http:\/\/community\.livejournal\.com\/${user}\/\d+.html)/sg)
 	    {
 		my $ch_url = $1;
 		if (!$remember_ch_urls{$ch_url})
@@ -499,12 +499,12 @@ sub parse_chapter_urls {
 	}
 	else
 	{
-	    while ($content =~ m/href="(http:\/\/${user}\.livejournal\.com\/\d+.html)(#cutid\d)?">/sg)
+	    while ($content =~ m/href="(http:\/\/${user}\.livejournal\.com\/\d+.html)/sg)
 	    {
 		my $ch_url = $1;
-		if (!$remember_ch_urls{$ch_url})
+                warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
+                if (!$remember_ch_urls{$ch_url})
 		{
-		    warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
 		    push @chapters, "${ch_url}?format=light";
                     $remember_ch_urls{$ch_url} = 1;
 		}
